# Download folder (same folder as script)
$downloadFolder = "$PSScriptRoot\SoftubeInstallers"
if (-not (Test-Path $downloadFolder)) {
    New-Item -ItemType Directory -Path $downloadFolder | Out-Null
}

# URL with installers
$url = "https://www.softube.com/support/support-getting-started/direct-installers-for-win_1"

Write-Host "Loading page with links..."

try {
    $response = Invoke-WebRequest -Uri $url -UseBasicParsing -ErrorAction Stop
} catch {
    Write-Host "Error loading page: $_" -ForegroundColor Red
    Read-Host "Press Enter to exit"
    exit
}

# Regex for links to .exe and .zip on CDN
$linkPattern = 'https://softubestorage\.b-cdn\.net/[^\s"''>]+?\.(exe|zip)'

$matches = [regex]::Matches($response.Content, $linkPattern)
$links = $matches | ForEach-Object { $_.Value } | Sort-Object -Unique

if ($links.Count -eq 0) {
    Write-Host "No download links found." -ForegroundColor Yellow
    Read-Host "Press Enter to exit"
    exit
}

Write-Host "Found files: $($links.Count)`n"

# User-Agent header
$headers = @{ "User-Agent" = "Mozilla/5.0 (Windows NT 10.0; Win64; x64)" }

for ($i = 0; $i -lt $links.Count; $i++) {
    $link = $links[$i]
    $fileName = Split-Path $link -Leaf

    # Decode URL-encoded characters in filename
    $fileName = $fileName -replace '%20', ' '
    $fileName = $fileName -replace '%28', '('
    $fileName = $fileName -replace '%29', ')'

    $destination = Join-Path $downloadFolder $fileName

    Write-Host "Downloading [$($i+1)/$($links.Count)]: $fileName"

    try {
        Invoke-WebRequest -Uri $link -OutFile $destination -Headers $headers -UseBasicParsing -ErrorAction Stop
        Write-Host "  Download successful."
    } catch {
        Write-Host "  Download error: $_" -ForegroundColor Red
    }
}

Write-Host "`nAll operations completed."
Read-Host "Press Enter to exit"
