# Ask the user to input a version number
$version = Read-Host "Enter the version to download (e.g., 2.6.6)"

# Download folder (same folder as the script)
$downloadFolder = "$PSScriptRoot\SoftubeInstallers"
if (-not (Test-Path $downloadFolder)) {
    New-Item -ItemType Directory -Path $downloadFolder | Out-Null
}

# URL with installers
$url = "https://www.softube.com/support/support-getting-started/direct-installers-for-win_1"

Write-Host "Loading page with links..."

try {
    $response = Invoke-WebRequest -Uri $url -UseBasicParsing -ErrorAction Stop
} catch {
    Write-Host "Error loading page: $_" -ForegroundColor Red
    Read-Host "Press Enter to exit"
    return
}

# Regex for links to .exe and .zip files on CDN
$linkPattern = 'https://softubestorage\.b-cdn\.net/[^\s"''>]+?\.(exe|zip)'

# Extract and filter links by version
$matches = [regex]::Matches($response.Content, $linkPattern)
$links = $matches | ForEach-Object { $_.Value } | Where-Object { $_ -match [regex]::Escape($version) } | Sort-Object -Unique

if ($links.Count -eq 0) {
    Write-Host "No files found for version $version." -ForegroundColor Yellow
    Read-Host "Press Enter to exit"
    return
}

Write-Host "Found $($links.Count) file(s) for version $version.`n"

# User-Agent header to avoid being blocked
$headers = @{ "User-Agent" = "Mozilla/5.0 (Windows NT 10.0; Win64; x64)" }

# Download each matching file
for ($i = 0; $i -lt $links.Count; $i++) {
    $link = $links[$i]
    $fileName = Split-Path $link -Leaf

    # Decode URL-encoded characters in filename
    $fileName = $fileName -replace '%20', ' '
    $fileName = $fileName -replace '%28', '('
    $fileName = $fileName -replace '%29', ')'

    $destination = Join-Path $downloadFolder $fileName

    Write-Host "Downloading [$($i+1)/$($links.Count)]: $fileName"

    try {
        Invoke-WebRequest -Uri $link -OutFile $destination -Headers $headers -UseBasicParsing -ErrorAction Stop
        Write-Host "  Download successful."
    } catch {
        Write-Host "  Download error: $_" -ForegroundColor Red
    }
}

Write-Host "`nAll operations completed."
Read-Host "Press Enter to exit"
