# Prompt the user to enter the path to the installers folder
$installersPath = Read-Host "Enter the path to the installers folder"

# Check if the specified folder exists
if (-Not (Test-Path $installersPath)) {
    Write-Host "The specified folder does not exist: $installersPath" -ForegroundColor Red
	Read-Host "Press Enter to exit"
    exit
}

$logFile = "$installersPath\install-log.txt"

# Create or clear the log file
"Installation started: $(Get-Date)" | Out-File -FilePath $logFile -Encoding UTF8

# Get all .exe installers
$installers = Get-ChildItem -Path $installersPath -Filter *.exe -File

# Installation loop
foreach ($installer in $installers) {
    $fullPath = $installer.FullName
    $logEntry = "Installation of $($installer.Name) started: $(Get-Date)"
    $logEntry | Out-File -FilePath $logFile -Append
    Write-Host $logEntry

    try {
        # Run with NSIS parameters: /S — completely silent installation
        Start-Process -FilePath $fullPath -ArgumentList "/S" -Wait

        "Installation of $($installer.Name) completed: $(Get-Date)" | Out-File -FilePath $logFile -Append
        Write-Host "Installed: $($installer.Name)"
    } catch {
        "❌ Error installing $($installer.Name): $_" | Out-File -FilePath $logFile -Append
        Write-Host "❌ Error installing: $($installer.Name)" -ForegroundColor Red
    }
}

"✅ All installations completed: $(Get-Date)" | Out-File -FilePath $logFile -Append
Write-Host "`nAll installations completed. Log: $logFile"
Read-Host "Press Enter to exit"
